Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInsufficientData = errors.New("kafka: insufficient data to decode packet, more bytes expected")
ErrInsufficientData is returned when decoding and the packet is truncated. This can be expected when requesting messages, since as an optimization the server is allowed to return a partial message at the end of the message set.
Functions ¶
func ParseConfluentCloudConfig ¶
TODO return []string for brokers
func TryFindCcloudConfigFile ¶
Types ¶
type Config ¶
type Config struct {
CurrentCluster string `yaml:"current-cluster"`
Clusters []*Cluster `yaml:"clusters"`
}
func ReadConfig ¶
func (*Config) ActiveCluster ¶
func (*Config) SetCurrentCluster ¶ added in v0.1.2
type PacketDecoder ¶
type PacketDecoder interface {
// contains filtered or unexported methods
}
func NewDecoder ¶
func NewDecoder(raw []byte) PacketDecoder
type SubscriptionInfo ¶
type SubscriptionInfo struct {
Version int32
UUID []byte // 16-byte UUID
ProcessID string
PrevTasks []TaskID
StandbyTasks []TaskID
UserEndpoint string
}
func (*SubscriptionInfo) Decode ¶
func (s *SubscriptionInfo) Decode(pd PacketDecoder) (err error)
Support version 1+2
Click to show internal directories.
Click to hide internal directories.